@@ -9,6 +9,7 @@ import Control.Monad.Trans.Maybe (MaybeT (..), runMaybeT)
 import Stackctl.AWS.CloudFormation
 import Stackctl.AWS.Core as AWS
 import Stackctl.AWS.Scope
+import Stackctl.DirectoryOption
 import Stackctl.FilterOption
 import UnliftIO.Directory (doesFileExist)
 
@@ -17,26 +18,30 @@ inferRemovedStacks
      , MonadAWS m
      , MonadReader env m
      , HasAwsScope env
+     , HasDirectoryOption env
      , HasFilterOption env
      )
   => m [Stack]
 inferRemovedStacks = do
   scope <- view awsScopeL
   paths <- view $ filterOptionL . to filterOptionToPaths
-  catMaybes <$> traverse (findRemovedStack scope) paths
+  dir <- view $ directoryOptionL . to unDirectoryOption
+  catMaybes <$> traverse (findRemovedStack scope dir) paths
 
 findRemovedStack
   :: (MonadUnliftIO m, MonadAWS m)
   => AwsScope
   -> FilePath
+  -- ^ Root directory
+  -> FilePath
   -> m (Maybe Stack)
-findRemovedStack scope path = runMaybeT $ do
+findRemovedStack scope dir path = runMaybeT $ do
   -- The filter is a full path to a specification in the current
   -- account/region...
   stackName <- hoistMaybe $ awsScopeSpecStackName scope path
 
   -- that no longer exists...
-  guard . not =<< doesFileExist path
+  guard . not =<< doesFileExist (dir </> path)
 
   -- but the Stack it would point to does
   MaybeT $ awsCloudFormationDescribeStackMaybe stackName
