@@ -6,7 +6,7 @@ where
 import Stackctl.Prelude
 
 import Data.Aeson
-import Stackctl.AWS.CloudFormation (changeSetFromResponse)
+import Stackctl.AWS.CloudFormation (ChangeSetType (..), changeSetFromResponse)
 import Stackctl.Colors
 import Stackctl.Spec.Changes.Format
 import System.FilePath ((-<.>))
@@ -28,7 +28,7 @@ formatChangeSetGolden :: FilePath -> Format -> IO (Golden Text)
 formatChangeSetGolden path fmt = do
   actual <-
     formatChangeSet noColors OmitFull "some-stack" fmt
-      . (changeSetFromResponse <=< decodeStrict)
+      . (changeSetFromResponse ChangeSetType_UPDATE <=< decodeStrict)
       . encodeUtf8
       <$> readFileUtf8 path
 
